@@ -653,6 +653,29 @@ arv_chunk_parser_status_get_type (void)
 
 #include "arvgvstream.h"
 
+GType
+arv_gv_stream_option_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_GV_STREAM_OPTION_NONE,
+			  "ARV_GV_STREAM_OPTION_NONE",
+			  "none" },
+			{ ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED,
+			  "ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED",
+			  "packet-socket-disabled" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvGvStreamOption"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 arv_gv_stream_socket_buffer_get_type (void)
 {
